@@ -6,8 +6,9 @@ import asyncio
 from math import ceil
 from typing import List
 
+from tonsdk.contract.wallet import WalletVersionEnum, Wallets
 from tonsdk.boc import Cell
-from tonsdk.utils import Address, bytes_to_b64str, b64str_to_bytes
+from tonsdk.utils import Address, bytes_to_b64str, b64str_to_bytes, to_nano
 
 from ton import TonlibClient
 import ton.tonlibjson
@@ -181,17 +182,18 @@ async def _get_all_wallet_transactions(client: TonlibClient, addr: str, limit: i
         }
         if len(tr['out_msgs']):
             tr_result['type'] = 'out'
-            tr_result['from'] = Address(addr).to_string(is_user_friendly=True)
-            tr_result['to'] = Address(tr['out_msgs'][0]['destination']['account_address']).to_string(is_user_friendly=True)
+            tr_result['from'] = Address(addr).to_string(True, True, True)
+            tr_result['to'] = Address(tr['out_msgs'][0]['destination']['account_address']).to_string(True, True, True)
             tr_result['value'] = int(tr['out_msgs'][0]['value'])
             tr_result['message'] = base64.b64decode(tr['out_msgs'][0]['msg_data']['text']).decode('utf-8') if tr['out_msgs'][0]['msg_data']['@type'] == 'msg.dataText' else ''
         else:
             tr_result['type'] = 'in'
-            tr_result['from'] = Address(tr['in_msg']['source']['account_address']).to_string(is_user_friendly=True)
+            tr_result['from'] = Address(tr['in_msg']['source']['account_address']).to_string(True, True, True)
             tr_result['to'] = Address(addr).to_string(is_user_friendly=True)
             tr_result['value'] = int(tr['in_msg']['value'])
             tr_result['message'] = base64.b64decode(tr['in_msg']['msg_data']['text']).decode('utf-8') if tr['in_msg']['msg_data']['@type'] == 'msg.dataText' else ''
         result.append(tr_result)
+    await client.tonlib_wrapper.close()
     return result
 
 
@@ -227,10 +229,7 @@ async def _get_nft_items_by_owner_address(client: TonlibClient, addr: str):
     client = await _get_client(client.ls_index)
 
     async def proc_tr(tr):
-
         if tr['type'] == 'in':
-            if 'EQBdHpUa1u3IVs1b3xfjpSlXVD5lkNsfIcJMqtXu1IJ0rLHK' == tr['from'] or 'EQBqkkKeF7cwbX-erNK73qs4fqpwkXNQd_yqS4HXzp3PaCSX' == tr['from']:
-                print(tr)
             account = await client.find_account(tr['from'])
             try:
                 nft_data = await account.get_nft_data()
@@ -244,6 +243,7 @@ async def _get_nft_items_by_owner_address(client: TonlibClient, addr: str):
                 return
 
     await asyncio.gather(*[proc_tr(tr) for tr in all_transactions])
+    await client.tonlib_wrapper.close()
     return list(result)
 
 
@@ -267,7 +267,35 @@ async def _get_collection_items(client: TonlibClient, addr: str):
 
     for p in range(ceil(items_amount / 10000)):
         await asyncio.gather(*[get_item_addr(i, result) for i in range(p * 10000, min(items_amount, 10000 * (p + 1)))])
-
+    await client.tonlib_wrapper.close()
     if len(result) < items_amount:
         raise Exception('GOT NOT ALL ITEMS')
     return result
+
+
+def transfer_ton(mnemonic: list, address: str, value: float, comment: str = '', wallet_version: str = 'v4r2', client: TonlibClient = None):
+    """
+    :param mnemonic: seed phrase of owner wallet
+    :param address: address to send Tons
+    :param value: value of Tons (e.g value=0.1 means that 0.1 Ton will be sent)
+    :param comment: comment of transaction
+    :param wallet_version: owner wallet version, default v4r2
+    :return:
+    """
+    if not client:
+        client = get_client(2)
+
+    return asyncio.get_event_loop().run_until_complete(_transfer_ton(client, mnemonic, address, value, comment, wallet_version))
+
+
+async def _transfer_ton(client: TonlibClient, mnemonic: list, address: str, value: float, comment: str, wallet_version: str):
+    mnemonics, _pub_k, _priv_k, wallet = Wallets.from_mnemonics(mnemonic, WalletVersionEnum(wallet_version), 0)
+    account = await client.find_account(wallet.address.to_string())
+    seqno = await account.seqno()
+    query = wallet.create_transfer_message(to_addr=address,
+                                          amount=to_nano(value, 'ton'),
+                                          seqno=seqno, payload=comment)
+    boc = query["message"].to_boc(False)
+    resp = await client.send_boc(boc)
+    await client.tonlib_wrapper.close()
+    return resp
\ No newline at end of file
